@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Optional, Set, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Type, Union, cast
 
 from openapi_schema_pydantic.util import construct_open_api_with_schema_class
 from openapi_schema_pydantic.v3.v3_1_0.open_api import OpenAPI
@@ -6,17 +6,15 @@ from pydantic import validate_arguments
 from pydantic.typing import AnyCallable
 from starlette.middleware import Middleware as StarletteMiddleware
 from starlette.middleware.cors import CORSMiddleware
-from starlette.middleware.gzip import GZipMiddleware
 from starlette.middleware.trustedhost import TrustedHostMiddleware
 from starlette.staticfiles import StaticFiles
 from starlette.types import ASGIApp, Receive, Scope, Send
-from typing_extensions import Type
 
 from starlite.asgi import StarliteASGIRouter
 from starlite.config import (
     CacheConfig,
+    CompressionConfig,
     CORSConfig,
-    GZIPConfig,
     OpenAPIConfig,
     StaticFilesConfig,
     TemplateConfig,
@@ -24,10 +22,9 @@ from starlite.config import (
 from starlite.datastructures import State
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers.asgi import ASGIRouteHandler, asgi
-from starlite.handlers.base import BaseRouteHandler
 from starlite.handlers.http import HTTPRouteHandler
-from starlite.handlers.websocket import WebsocketRouteHandler
 from starlite.middleware import ExceptionHandlerMiddleware
+from starlite.middleware.compression.base import CompressionMiddleware
 from starlite.openapi.path_item import create_path_item
 from starlite.plugins.base import PluginProtocol
 from starlite.provide import Provide
@@ -48,6 +45,10 @@ from starlite.types import (
 from starlite.utils import normalize_path
 from starlite.utils.templates import create_template_engine
 
+if TYPE_CHECKING:
+    from starlite.handlers.base import BaseRouteHandler
+    from starlite.handlers.websocket import WebsocketRouteHandler
+
 DEFAULT_OPENAPI_CONFIG = OpenAPIConfig(title="Starlite API", version="1.0.0")
 DEFAULT_CACHE_CONFIG = CacheConfig()
 
@@ -60,7 +61,7 @@ class Starlite(Router):
         "cache_config",
         "cors_config",
         "debug",
-        "gzip_config",
+        "compression_config",
         "openapi_schema",
         "plain_routes",
         "plugins",
@@ -83,7 +84,7 @@ class Starlite(Router):
         dependencies: Optional[Dict[str, Provide]] = None,
         exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
         guards: Optional[List[Guard]] = None,
-        gzip_config: Optional[GZIPConfig] = None,
+        compression_config: Optional[CompressionConfig] = None,
         middleware: Optional[List[Middleware]] = None,
         on_shutdown: Optional[List[LifeCycleHandler]] = None,
         on_startup: Optional[List[LifeCycleHandler]] = None,
@@ -99,7 +100,7 @@ class Starlite(Router):
         self.cache_config = cache_config
         self.cors_config = cors_config
         self.debug = debug
-        self.gzip_config = gzip_config
+        self.compression_config = compression_config
         self.plain_routes: Set[str] = set()
         self.plugins = plugins or []
         self.route_map: Dict[str, Any] = {}
@@ -117,9 +118,9 @@ class Starlite(Router):
             before_request=before_request,
             after_request=after_request,
             middleware=middleware,
+            exception_handlers=exception_handlers,
         )
 
-        self.exception_handlers: Dict[Union[int, Type[Exception]], ExceptionHandler] = exception_handlers or {}
         self.asgi_router = StarliteASGIRouter(on_shutdown=on_shutdown or [], on_startup=on_startup or [], app=self)
         self.asgi_handler = self.create_asgi_handler()
         self.openapi_schema: Optional[OpenAPI] = None
@@ -139,19 +140,16 @@ class Starlite(Router):
         """
         Creates an ASGIApp that wraps the ASGI router inside an exception handler.
 
-        If CORS or TruseedHost configs are provided to the constructor, they will wrap the router as well.
+        If CORS or TrustedHost configs are provided to the constructor, they will wrap the router as well.
         """
         asgi_handler: ASGIApp = self.asgi_router
-        if self.gzip_config:
-            asgi_handler = GZipMiddleware(app=asgi_handler, **self.gzip_config.dict())
+        if self.compression_config:
+            asgi_handler = CompressionMiddleware(app=asgi_handler, config=self.compression_config)
         if self.allowed_hosts:
             asgi_handler = TrustedHostMiddleware(app=asgi_handler, allowed_hosts=self.allowed_hosts)
         if self.cors_config:
             asgi_handler = CORSMiddleware(app=asgi_handler, **self.cors_config.dict())
-        return self.wrap_in_exception_handler(
-            asgi_handler,
-            exception_handlers=self.exception_handlers,
-        )
+        return self.wrap_in_exception_handler(asgi_handler, exception_handlers=self.exception_handlers or {})
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         """
@@ -174,60 +172,74 @@ class Starlite(Router):
 
         return ExceptionHandlerMiddleware(app=app, exception_handlers=exception_handlers, debug=self.debug)
 
-    def construct_route_map(self) -> None:  # noqa: C901 # pylint: disable=R0912
+    def add_node_to_route_map(self, route: BaseRoute) -> Dict[str, Any]:
+        """
+        Adds a new route path (e.g. '/foo/bar/{param:int}') into the route_map tree.
+
+        Inserts non-parameter paths ('plain routes') off the tree's root node.
+        For paths containing parameters, splits the path on '/' and nests each path
+        segment under the previous segment's node (see prefix tree / trie).
+        """
+        cur_node = self.route_map
+        path = route.path
+        if route.path_parameters or path in self.static_paths:
+            for param_definition in route.path_parameters:
+                path = path.replace(param_definition["full"], "")
+            path = path.replace("{}", "*")
+            components = ["/", *[component for component in path.split("/") if component]]
+            for component in components:
+                components_set = cast(Set[str], cur_node["_components"])
+                components_set.add(component)
+                if component not in cur_node:
+                    cur_node[component] = {"_components": set()}
+                cur_node = cast(Dict[str, Any], cur_node[component])
+        else:
+            if path not in self.route_map:
+                self.route_map[path] = {"_components": set()}
+            self.plain_routes.add(path)
+            cur_node = self.route_map[path]
+        self.configure_route_map_node(route, cur_node)
+        return cur_node
+
+    def configure_route_map_node(self, route: BaseRoute, node: Dict[str, Any]) -> None:
+        """
+        Set required attributes and route handlers on route_map tree node.
+        """
+        if "_path_parameters" not in node:
+            node["_path_parameters"] = route.path_parameters
+        if "_asgi_handlers" not in node:
+            node["_asgi_handlers"] = {}
+        if "_is_asgi" not in node:
+            node["_is_asgi"] = False
+        if route.path in self.static_paths:
+            node["static_path"] = route.path
+            node["_is_asgi"] = True
+        asgi_handlers = cast(Dict[str, ASGIApp], node["_asgi_handlers"])
+        if isinstance(route, HTTPRoute):
+            for method, handler_mapping in route.route_handler_map.items():
+                handler, _ = handler_mapping
+                asgi_handlers[method] = self.build_route_middleware_stack(route, handler)
+        elif isinstance(route, WebSocketRoute):
+            asgi_handlers["websocket"] = self.build_route_middleware_stack(route, route.route_handler)
+        elif isinstance(route, ASGIRoute):
+            asgi_handlers["asgi"] = self.build_route_middleware_stack(route, route.route_handler)
+            node["_is_asgi"] = True
+
+    def construct_route_map(self) -> None:
         """
         Create a map of the app's routes. This map is used in the asgi router to route requests.
-
         """
-        seen_param_paths = set()
         if "_components" not in self.route_map:
             self.route_map["_components"] = set()
         for route in self.routes:
-            path = route.path
-            if route.path_parameters or path in self.static_paths:
-                for param_definition in route.path_parameters:
-                    path = path.replace(param_definition["full"], "")
-                path = path.replace("{}", "*")
-                if path in seen_param_paths:
-                    raise ImproperlyConfiguredException("Should not use routes with conflicting path parameters")
-                seen_param_paths.add(path)
-                cur = self.route_map
-                components = ["/", *[component for component in path.split("/") if component]]
-                for component in components:
-                    components_set = cast(Set[str], cur["_components"])
-                    components_set.add(component)
-                    if component not in cur:
-                        cur[component] = {"_components": set()}
-                    cur = cast(Dict[str, Any], cur[component])
-            else:
-                if path not in self.route_map:
-                    self.route_map[path] = {"_components": set()}
-                self.plain_routes.add(path)
-                cur = self.route_map[path]
-            if "_path_parameters" not in cur:
-                cur["_path_parameters"] = route.path_parameters
-            if "_asgi_handlers" not in cur:
-                cur["_asgi_handlers"] = {}
-            if "_is_asgi" not in cur:
-                cur["_is_asgi"] = False
-            if path in self.static_paths:
-                cur["static_path"] = path
-                cur["_is_asgi"] = True
-            asgi_handlers = cast(Dict[str, ASGIApp], cur["_asgi_handlers"])
-            if isinstance(route, HTTPRoute):
-                for method, handler_mapping in route.route_handler_map.items():
-                    handler, _ = handler_mapping
-                    asgi_handlers[method] = self.build_route_middleware_stack(route, handler)
-            elif isinstance(route, WebSocketRoute):
-                asgi_handlers["websocket"] = self.build_route_middleware_stack(route, route.route_handler)
-            elif isinstance(route, ASGIRoute):
-                asgi_handlers["asgi"] = self.build_route_middleware_stack(route, route.route_handler)
-                cur["_is_asgi"] = True
+            node = self.add_node_to_route_map(route)
+            if node["_path_parameters"] != route.path_parameters:
+                raise ImproperlyConfiguredException("Should not use routes with conflicting path parameters")
 
     def build_route_middleware_stack(
         self,
         route: Union[HTTPRoute, WebSocketRoute, ASGIRoute],
-        route_handler: Union[HTTPRouteHandler, WebsocketRouteHandler, ASGIRouteHandler],
+        route_handler: Union[HTTPRouteHandler, "WebsocketRouteHandler", ASGIRouteHandler],
     ) -> ASGIApp:
         """Constructs a middleware stack that serves as the point of entry for each route"""
 
@@ -273,7 +285,7 @@ class Starlite(Router):
                 route.handler_parameter_model = route.create_handler_kwargs_model(route.route_handler)
         self.construct_route_map()
 
-    def create_handler_signature_model(self, route_handler: BaseRouteHandler) -> None:
+    def create_handler_signature_model(self, route_handler: "BaseRouteHandler") -> None:
         """
         Creates function signature models for all route handler functions and provider dependencies
         """
