@@ -1,10 +1,21 @@
 from dataclasses import asdict, is_dataclass
-from typing import Any, Dict, Generic, List, Optional, Tuple, TypeVar, Union, cast
+from typing import (
+    Any,
+    ClassVar,
+    Dict,
+    Generic,
+    List,
+    Optional,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+    cast,
+)
 
 from pydantic import BaseConfig, BaseModel, create_model
 from pydantic.fields import SHAPE_SINGLETON, ModelField, Undefined
 from pydantic.generics import GenericModel
-from typing_extensions import ClassVar, Type
 
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.plugins import PluginProtocol, get_plugin_for_value
@@ -106,7 +117,7 @@ class DTOFactory:
 
         This will affect parsing, validation and how OpenAPI schema is generated exactly like when using a pydantic model.
 
-        Note: Although the value generated is a pydantic factory, because it is being generated programmaticaly,
+        Note: Although the value generated is a pydantic factory, because it is being generated programmatically,
         it's currently not possible to extend editor auto-complete for the DTO properties - it will be typed as a
         Pydantic BaseModel, but no attributes will be inferred in the editor.
         """
