@@ -1,16 +1,18 @@
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 
 from openapi_schema_pydantic.v3.v3_1_0.media_type import (
     MediaType as OpenAPISchemaMediaType,
 )
 from openapi_schema_pydantic.v3.v3_1_0.request_body import RequestBody
-from pydantic.fields import ModelField
 
 from starlite.enums import RequestEncodingType
 from starlite.openapi.schema import create_schema, update_schema_with_field_info
 
+if TYPE_CHECKING:  # pragma: no cover
+    from pydantic.fields import ModelField
 
-def create_request_body(field: ModelField, generate_examples: bool) -> Optional[RequestBody]:
+
+def create_request_body(field: "ModelField", generate_examples: bool) -> Optional[RequestBody]:
     """
     Create a RequestBody model for the given RouteHandler or return None
     """
