@@ -1,17 +1,17 @@
 import re
 from typing import TYPE_CHECKING, List, Optional
 
-from pydantic.fields import ModelField
-
 from starlite.exceptions import ImproperlyConfiguredException
-from starlite.handlers.http import HTTPRouteHandler
 from starlite.openapi.constants import PYDANTIC_FIELD_SHAPE_MAP
-from starlite.openapi.enums import OpenAPIType
 
 if TYPE_CHECKING:  # pragma: no cover
     from typing import Union
 
+    from pydantic.fields import ModelField
+
     from starlite import Controller, Router, Starlite
+    from starlite.handlers.http import HTTPRouteHandler
+    from starlite.openapi.enums import OpenAPIType
 
 
 CAPITAL_LETTERS_PATTERN = re.compile(r"(?=[A-Z])")
@@ -22,7 +22,7 @@ def pascal_case_to_text(s: str) -> str:
     return " ".join(re.split(CAPITAL_LETTERS_PATTERN, s)).strip()
 
 
-def extract_tags_from_route_handler(route_handler: HTTPRouteHandler) -> Optional[List[str]]:
+def extract_tags_from_route_handler(route_handler: "HTTPRouteHandler") -> Optional[List[str]]:
     """Extracts and combines tags from route_handler and any owners"""
     child_tags = route_handler.tags or []
     parent_tags: List[str] = []
@@ -36,7 +36,7 @@ def extract_tags_from_route_handler(route_handler: HTTPRouteHandler) -> Optional
     return list(set(child_tags) | set(parent_tags)) or None
 
 
-def get_openapi_type_for_complex_type(field: ModelField) -> OpenAPIType:
+def get_openapi_type_for_complex_type(field: "ModelField") -> "OpenAPIType":
     """
     We are dealing with complex types in this case.
 
