@@ -1,10 +1,11 @@
-from typing import List, Union
-
-from pydantic import DirectoryPath
+from typing import TYPE_CHECKING, List, Union
 
 from starlite.exceptions import MissingDependencyException, TemplateNotFound
 from starlite.template.base import TemplateEngineProtocol
 
+if TYPE_CHECKING:  # pragma: no cover
+    from pydantic import DirectoryPath
+
 try:
     from mako.exceptions import TemplateLookupException as MakoTemplateNotFound
     from mako.lookup import TemplateLookup
@@ -16,7 +17,7 @@ except ImportError as exc:  # pragma: no cover
 class MakoTemplateEngine(TemplateEngineProtocol[MakoTemplate]):
     """Template engine using the mako templating library"""
 
-    def __init__(self, directory: Union[DirectoryPath, List[DirectoryPath]]) -> None:
+    def __init__(self, directory: Union["DirectoryPath", List["DirectoryPath"]]) -> None:
         super().__init__(directory)
         self.engine = TemplateLookup(directories=directory if isinstance(directory, (list, tuple)) else [directory])
 
